==> amarok-2.9.70_pre20190111.tar.xz: amarok-2.9.70_pre20190111/src/toolbar/CurrentTrackToolbar.h <==
/****************************************************************************************
 * Copyright (c) 2009  Nikolaj Hald Nielsen <nhn@kde.org>                               *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef CURRENTTRACKTOOLBAR_H
#define CURRENTTRACKTOOLBAR_H

#include <QToolBar>

/** A toolbar that contains the CurrentTrackActions of the currently playing track.
*/
class CurrentTrackToolbar : public QToolBar
{
    Q_OBJECT

public:
    explicit CurrentTrackToolbar( QWidget * parent );

    ~CurrentTrackToolbar();

protected Q_SLOTS:
    void handleAddActions();
};

#endif

==> amarok-3.0.81.tar.xz: amarok-3.0.81/src/toolbar/CurrentTrackToolbar.h <==
/****************************************************************************************
 * Copyright (c) 2009  Nikolaj Hald Nielsen <nhn@kde.org>                               *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef CURRENTTRACKTOOLBAR_H
#define CURRENTTRACKTOOLBAR_H

#include <QToolBar>

/** A toolbar that contains the CurrentTrackActions of the currently playing track.
*/
class CurrentTrackToolbar : public QToolBar
{
    Q_OBJECT

public:
    explicit CurrentTrackToolbar( QWidget * parent );

    ~CurrentTrackToolbar() override;

protected Q_SLOTS:
    void handleAddActions();
};

#endif
